==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/client/foundation/gui/render/CrushWheelRenderer.java <==
package com.zurrtum.create.client.foundation.gui.render;

import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.client.catnip.animation.AnimationTickHolder;
import com.zurrtum.create.client.flywheel.lib.model.baked.SinglePosVirtualBlockGetter;
import java.util.List;
import net.minecraft.class_10889;
import net.minecraft.class_11239;
import net.minecraft.class_2338;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_2680;
import net.minecraft.class_2741;
import net.minecraft.class_308;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4722;
import net.minecraft.class_776;
import net.minecraft.class_7833;

public class CrushWheelRenderer extends class_11239<CrushWheelRenderState> {
    private final class_2680 blockState = AllBlocks.CRUSHING_WHEEL.method_9564().method_11657(class_2741.field_12496, class_2351.field_11048);

    public CrushWheelRenderer(class_4597.class_4598 vertexConsumers) {
        super(vertexConsumers);
    }

    @Override
    protected void render(CrushWheelRenderState state, class_4587 matrices) {
        class_310 mc = class_310.method_1551();
        mc.field_1773.method_71114().method_71034(class_308.class_11274.field_60028);
        matrices.method_22905(1, 1, -1);
        matrices.method_22907(class_7833.field_40716.rotationDegrees(-22.5f));
        matrices.method_46416(-1.5f, -0.6f, -0.5f);
        matrices.method_22905(1, -1, 1);

        class_776 blockRenderManager = mc.method_1541();
        SinglePosVirtualBlockGetter world = SinglePosVirtualBlockGetter.createFullBright();
        class_4588 buffer = field_59933.method_73477(class_4722.method_24074());
        List<class_10889> parts = blockRenderManager.method_3349(blockState).method_68512(mc.field_1687.field_9229);
        world.blockState(blockState);

        float angle = getCurrentAngle();
        matrices.method_22903();
        matrices.method_46416(0.5f, 0.5f, 0.5f);
        matrices.method_22907(class_7833.field_40718.rotationDegrees(-angle));
        matrices.method_22907(class_7833.field_40716.rotationDegrees(90));
        matrices.method_46416(-0.5f, -0.5f, -0.5f);
        blockRenderManager.method_3355(blockState, class_2338.field_10980, world, matrices, buffer, false, parts);
        matrices.method_22909();

        matrices.method_46416(0.5f, 0.5f, 0.5f);
        matrices.method_46416(2, 0, 0);
        matrices.method_22907(class_7833.field_40718.rotationDegrees(angle));
        matrices.method_22907(class_7833.field_40716.rotationDegrees(90));
        matrices.method_46416(-0.5f, -0.5f, -0.5f);
        blockRenderManager.method_3355(blockState, class_2338.field_10980, world, matrices, buffer, false, parts);
    }

    public static float getCurrentAngle() {
        return (AnimationTickHolder.getRenderTime() * 4f) % 360;
    }

    @Override
    public Class<CrushWheelRenderState> method_70903() {
        return CrushWheelRenderState.class;
    }

    @Override
    protected String method_70906() {
        return "Crush Wheel";
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/foundation/gui/render/CrushWheelRenderer.java <==
package com.zurrtum.create.client.foundation.gui.render;

import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.client.catnip.animation.AnimationTickHolder;
import com.zurrtum.create.client.flywheel.lib.model.baked.SinglePosVirtualBlockGetter;
import java.util.List;
import net.minecraft.class_10889;
import net.minecraft.class_11239;
import net.minecraft.class_2338;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_2680;
import net.minecraft.class_2741;
import net.minecraft.class_308;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4722;
import net.minecraft.class_776;

public class CrushWheelRenderer extends class_11239<CrushWheelRenderState> {
    private final class_2680 blockState = AllBlocks.CRUSHING_WHEEL.method_9564().method_11657(class_2741.field_12496, class_2351.field_11048);

    public CrushWheelRenderer(class_4597.class_4598 vertexConsumers) {
        super(vertexConsumers);
    }

    @Override
    protected void renderToTexture(CrushWheelRenderState state, class_4587 matrices) {
        class_310 mc = class_310.method_1551();
        mc.field_1773.method_71114().method_71034(class_308.class_11274.field_60028);
        matrices.method_22905(1, 1, -1);
        matrices.method_22907(net.minecraft.class_7833.field_40716.rotationDegrees(-22.5f));
        matrices.method_46416(-1.5f, -0.6f, -0.5f);
        matrices.method_22905(1, -1, 1);

        class_776 blockRenderManager = mc.method_1541();
        SinglePosVirtualBlockGetter world = SinglePosVirtualBlockGetter.createFullBright();
        class_4588 buffer = field_59933.method_73477(class_4722.method_24074());
        List<class_10889> parts = blockRenderManager.method_3349(blockState).method_68512(mc.field_1687.field_9229);
        world.blockState(blockState);

        float angle = getCurrentAngle();
        matrices.method_22903();
        matrices.method_46416(0.5f, 0.5f, 0.5f);
        matrices.method_22907(net.minecraft.class_7833.field_40718.rotationDegrees(-angle));
        matrices.method_22907(net.minecraft.class_7833.field_40716.rotationDegrees(90));
        matrices.method_46416(-0.5f, -0.5f, -0.5f);
        blockRenderManager.method_3355(blockState, class_2338.field_10980, world, matrices, buffer, false, parts);
        matrices.method_22909();

        matrices.method_46416(0.5f, 0.5f, 0.5f);
        matrices.method_46416(2, 0, 0);
        matrices.method_22907(net.minecraft.class_7833.field_40718.rotationDegrees(angle));
        matrices.method_22907(net.minecraft.class_7833.field_40716.rotationDegrees(90));
        matrices.method_46416(-0.5f, -0.5f, -0.5f);
        blockRenderManager.method_3355(blockState, class_2338.field_10980, world, matrices, buffer, false, parts);
    }

    public static float getCurrentAngle() {
        return (AnimationTickHolder.getRenderTime() * 4f) % 360;
    }

    @Override
    public Class<CrushWheelRenderState> method_70903() {
        return CrushWheelRenderState.class;
    }

    @Override
    protected String method_70906() {
        return "Crush Wheel";
    }
}
